Changelog
=========

1.1 (2023-06-30)
--------------------

* Better documentation
* Better Reader class with the ultraspy format
* Fixed the Matricial Probe and pitches in Convex
* Added the PW / DW delays
